#!/bin/sh

# Script used as entrypoint for KC and VDP environments.

set -ex -o pipefail

export JAVA_OPTS="-showversion \
-XX:+PrintFlagsFinal \
-XX:+PrintCommandLineFlags \
-XX:+PrintStringTableStatistics \
-XX:ErrorFile=/tmp/error_java_access_%p.log \
-Xlog:gc*:/tmp/access.txt:time,level,tags:filesize=50M,filecount=1 \
-Xloggc:/tmp/access.txt \
-Xms${JVM_XMS:-768m} -Xmx${JVM_XMX:-1536m} \
-Xss384k \
-XX:MaxJavaStackTraceDepth=0 \
-XX:SurvivorRatio=8 \
-XX:TargetSurvivorRatio=90 \
-XX:MaxTenuringThreshold=15 \
-XX:ParallelGCThreads=4 \
-XX:+OptimizeStringConcat \
-XX:MaxMetaspaceSize=256m"

MULTI_ENVS=()
IFS=',' read -ra MULTI_ENVS <<< $(echo "${ENV}")

if [[ -n "${MULTIENV_CONNECTORS}" ]]; then
	API_KEY=""
	CONNECTOR_ID=""
	CONN_SEC_ENVS=$(echo "$MULTIENV_CONNECTORS" | jq -Mr 'keys_unsorted[]')
	for env in ${MULTI_ENVS[@]}; do
		if [[ `echo "${CONN_SEC_ENVS[@]}" | grep $env` ]]; then
			API_KEY="${API_KEY},$(echo ${MULTIENV_CONNECTORS} | jq -Mr '.'"$env"'."api-key"' )"
			CONNECTOR_ID="${CONNECTOR_ID},$(echo ${MULTIENV_CONNECTORS} | jq -Mr '.'"$env"'."connector-id"' )"
		fi
	done
	API_KEY=${API_KEY:1}
	CONNECTOR_ID=${CONNECTOR_ID:1}
fi

java ${JAVA_OPTS} -jar /app/access.jar --spring.config.location=/app/conf/application.properties &
PID=$!

EXITCODE=0
wait "$PID" || EXITCODE=$?
echo "Java process exited with $EXITCODE"
exit "$EXITCODE"
